Description Usage Format Details
This is a vector of audit measures describing the measures used to look at casemix from the 72hrs Cohorts.
1 |
An object of class tbl_df (inherits from tbl, data.frame) with 22 rows and 4 columns.
Internally it is used to create the Casemix tab in the portfolio.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.