This is a vector of audit measures describing the measures used to create the all patient post-72hr key indicators. This is used in performance reporting.
1 |
An object of class tbl_df (inherits from tbl, data.frame) with 13 rows and 3 columns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.